==> mdx-m3-viewer-4.0.15.tgz: package/src/index.js <==
import './math/gl-matrix-addon';

import * as common from './common';
import ModelViewer from './viewer';
import Scene from './scene';
import Camera from './camera';
import UnitTester from './unittester';
import * as glMatrix from 'gl-matrix';
import Blp from './handlers/blp/handler';
import Bmp from './handlers/bmp/handler';
import Dds from './handlers/dds/handler';
import Geo from './handlers/geo/handler';
import * as geometry from './handlers/geo/geometry';
import M3 from './handlers/m3/handler';
import Mdx from './handlers/mdx/handler';
import MdxParser from './handlers/mdx/parser/parser';
import MdxSanityTester from './handlers/mdx/parser/sanitytester';
import Mpq from './handlers/mpq/handler';
import NativeTexture from './handlers/nativetexture/handler';
import Obj from './handlers/obj/handler';
import Slk from './handlers/slk/handler';
import Tga from './handlers/tga/handler';
import W3x from './handlers/w3x/handler';
import MpqArchive from './handlers/mpq/parser/archive';
import W3xMap from './handlers/w3x/parser/map';
import stringToBuffer from './common/stringtobuffer';
import BinaryReader from './binaryreader';
import BinaryWriter from './binarywriter';

export {
    ModelViewer,
    common,
    Scene,
    Camera,
    UnitTester,
    glMatrix,
    Blp,
    Bmp,
    Dds,
    Geo,
    geometry,
    M3,
    Mdx,
    MdxParser,
    MdxSanityTester,
    Mpq,
    NativeTexture,
    Obj,
    Slk,
    Tga,
    W3x,
    MpqArchive,
    W3xMap,
    stringToBuffer,
    BinaryReader,
    BinaryWriter
};

==> mdx-m3-viewer-4.0.16.tgz: package/src/index.js <==
import './math/gl-matrix-addon';

import * as common from './common';
import ModelViewer from './viewer';
import Scene from './scene';
import Camera from './camera';
import UnitTester from './unittester';
import * as glMatrix from 'gl-matrix';
import Blp from './handlers/blp/handler';
import Bmp from './handlers/bmp/handler';
import Dds from './handlers/dds/handler';
import Geo from './handlers/geo/handler';
import * as geometry from './handlers/geo/geometry';
import M3 from './handlers/m3/handler';
import Mdx from './handlers/mdx/handler';
import MdxParser from './handlers/mdx/parser/parser';
import MdxSanityTester from './handlers/mdx/parser/sanitytester';
import Mpq from './handlers/mpq/handler';
import NativeTexture from './handlers/nativetexture/handler';
import Obj from './handlers/obj/handler';
import Slk from './handlers/slk/handler';
import Tga from './handlers/tga/handler';
import W3x from './handlers/w3x/handler';
import MpqArchive from './handlers/mpq/parser/archive';
import W3xMap from './handlers/w3x/parser/map';
import { stringToBuffer, bufferToString } from './common/stringtobuffer';
import BinaryReader from './binaryreader';
import BinaryWriter from './binarywriter';

export {
    ModelViewer,
    common,
    Scene,
    Camera,
    UnitTester,
    glMatrix,
    Blp,
    Bmp,
    Dds,
    Geo,
    geometry,
    M3,
    Mdx,
    MdxParser,
    MdxSanityTester,
    Mpq,
    NativeTexture,
    Obj,
    Slk,
    Tga,
    W3x,
    MpqArchive,
    W3xMap,
    stringToBuffer,
    bufferToString,
    BinaryReader,
    BinaryWriter
};
